How-tos
=======


.. toctree::
   :maxdepth: 2

   move_axes
   label_axes
   nus
   add_text
   boilerplate

Other planned topics
--------------------


* Gridspec

* How to make a legend for a figure and not axes? (feat. ``cleanup_figure()``)

